
# Type: anatomical entity to anatomical entity part of association_object




URI: [biolink:anatomical_entity_to_anatomical_entity_part_of_association_object](https://w3id.org/biolink/vocab/anatomical_entity_to_anatomical_entity_part_of_association_object)


## Domain and Range

[AnatomicalEntityToAnatomicalEntityPartOfAssociation](AnatomicalEntityToAnatomicalEntityPartOfAssociation.md) ->  <sub>REQ</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [anatomical entity to anatomical entity association➞object](anatomical_entity_to_anatomical_entity_association_object.md)

## Children


## Used by

 * [AnatomicalEntityToAnatomicalEntityPartOfAssociation](AnatomicalEntityToAnatomicalEntityPartOfAssociation.md)
